semanticLabel property

String? semanticLabel
final

Semantic label for accessibility.

This label is announced by screen readers to describe the PIN field. If not provided, a default label based on the field length is used.

Example:

PinInput(
  length: 6,
  semanticLabel: 'Enter 6-digit verification code',
  // ...
)

Implementation

final String? semanticLabel;