maybeOf static method
Gets the PinInputScope from the widget tree, or null if not found.
Implementation
static PinInputScope? maybeOf(BuildContext context) {
return context.dependOnInheritedWidgetOfExactType<PinInputScope>();
}
Gets the PinInputScope from the widget tree, or null if not found.
static PinInputScope? maybeOf(BuildContext context) {
return context.dependOnInheritedWidgetOfExactType<PinInputScope>();
}